@@ -21,30 +21,31 @@ import functools
 import logging
 import sys
 import typing
-from datetime import date
-from datetime import datetime
+from datetime import date, datetime
 from http import HTTPStatus
 
 from cryptography import x509
+from cryptography.x509.oid import ExtensionOID
 
 from django.contrib import admin
 from django.contrib.admin.views.main import ChangeList
 from django.contrib.messages import constants as messages
-from django.core.exceptions import PermissionDenied
+from django.core.exceptions import ImproperlyConfigured, PermissionDenied
 from django.core.handlers.wsgi import WSGIRequest
 from django.db import models
 from django.forms import ModelForm
 from django.forms.widgets import MediaDefiningClass
-from django.http import Http404
-from django.http import HttpRequest
-from django.http import HttpResponse
-from django.http import HttpResponseBadRequest
-from django.http import HttpResponseRedirect
-from django.http import JsonResponse
+from django.http import (
+    Http404,
+    HttpRequest,
+    HttpResponse,
+    HttpResponseBadRequest,
+    HttpResponseRedirect,
+    JsonResponse,
+)
 from django.template.loader import render_to_string
 from django.template.response import TemplateResponse
-from django.urls import path
-from django.urls import reverse
+from django.urls import path, reverse
 from django.urls.resolvers import URLPattern
 from django.utils import timezone
 from django.utils.html import format_html
@@ -53,37 +54,27 @@ from django.utils.translation import gettext_lazy as _
 from django_object_actions import DjangoObjectActions
 
 from . import ca_settings
-from .constants import ReasonFlags
-from .extensions import ExtendedKeyUsage
-from .extensions import KeyUsage
-from .extensions import SubjectAlternativeName
-from .extensions import TLSFeature
-from .extensions import get_extension_name
+from .constants import EXTENSION_DEFAULT_CRITICAL, EXTENSION_KEY_OIDS, EXTENSION_KEYS, ReasonFlags
+from .extensions import CERTIFICATE_EXTENSIONS, get_extension_name, serialize_extension
 from .extensions.utils import extension_as_admin_html
-from .forms import CreateCertificateForm
-from .forms import ResignCertificateForm
-from .forms import RevokeCertificateForm
-from .forms import X509CertMixinAdminForm
-from .models import AcmeAccount
-from .models import AcmeAuthorization
-from .models import AcmeCertificate
-from .models import AcmeChallenge
-from .models import AcmeOrder
-from .models import Certificate
-from .models import CertificateAuthority
-from .models import Watcher
-from .models import X509CertMixin
+from .forms import CreateCertificateForm, ResignCertificateForm, RevokeCertificateForm, X509CertMixinAdminForm
+from .models import (
+    AcmeAccount,
+    AcmeAuthorization,
+    AcmeCertificate,
+    AcmeChallenge,
+    AcmeOrder,
+    Certificate,
+    CertificateAuthority,
+    Watcher,
+)
 from .profiles import profiles
 from .querysets import CertificateQuerySet
 from .signals import post_issue_cert
-from .utils import OID_NAME_MAPPINGS
-from .utils import SERIAL_RE
-from .utils import add_colons
-from .utils import format_name
-from .utils import x509_name
+from .typehints import CRLExtensionType, X509CertMixinTypeVar
+from .utils import OID_NAME_MAPPINGS, SERIAL_RE, add_colons, format_name
 
 log = logging.getLogger(__name__)
-X509CertMixinTypeVar = typing.TypeVar("X509CertMixinTypeVar", bound=X509CertMixin)
 
 if typing.TYPE_CHECKING:
     AcmeAccountAdminBase = admin.ModelAdmin[AcmeAccount]
@@ -265,8 +256,7 @@ class CertificateMixin(
     def output_template(self, obj: X509CertMixinTypeVar, oid: x509.ObjectIdentifier) -> str:
         """Render extension for the given object."""
 
-        # PYLINT NOTE: use internal property until we can deprecate extensions
-        ext = obj._x509_extensions.get(oid)  # pylint: disable=protected-access
+        ext = obj.x509_extensions.get(oid)
 
         if ext is None:
             # SubjectAlternativeName is displayed unconditionally in the main section, so a certificate
@@ -281,7 +271,7 @@ class CertificateMixin(
             func = functools.partial(self.output_template, oid=oid)
             func.short_description = get_extension_name(oid)  # type: ignore[attr-defined]  # django standard
             return func
-        raise AttributeError
+        raise AttributeError(name)
 
     def get_oid_name(self, oid: x509.ObjectIdentifier) -> str:
         """Get a normalized name for the given OID."""
@@ -297,7 +287,7 @@ class CertificateMixin(
             return fieldsets
 
         fieldsets = copy.deepcopy(fieldsets)
-        for ext in obj._sorted_extensions:  # pylint: disable=protected-access
+        for ext in obj.sorted_extensions:
             field = self.get_oid_name(ext.oid)
             fieldsets[self.x509_fieldset_index][1]["fields"].append(field)
         return fieldsets
@@ -319,8 +309,7 @@ class CertificateMixin(
             # We can only change the date when the certificate was compromised if it's actually revoked.
             fields.append("compromised")
 
-        # pylint: disable-next=protected-access
-        extension_fields = [self.get_oid_name(oid) for oid in obj._x509_extensions]
+        extension_fields = [self.get_oid_name(oid) for oid in obj.x509_extensions]
         return list(fields) + extension_fields
 
     class Media:  # pylint: disable=missing-class-docstring
@@ -428,7 +417,7 @@ class CertificateAuthorityAdmin(CertificateMixin[CertificateAuthority], Certific
 
         return fieldsets
 
-    class Media:  # pylint: disable=missing-class-docstring
+    class Media:
         css = {
             "all": (
                 "django_ca/admin/css/base.css",
@@ -617,11 +606,11 @@ class CertificateAdmin(DjangoObjectActions, CertificateMixin[Certificate], Certi
         (
             _("X.509 Extensions"),
             {
-                "fields": [
-                    "key_usage",
-                    "extended_key_usage",
-                    "tls_feature",
-                ]
+                "fields": CERTIFICATE_EXTENSIONS,
+                "classes": (
+                    "collapse",
+                    "x509-extensions",
+                ),
             },
         ),
     ]
@@ -644,20 +633,35 @@ class CertificateAdmin(DjangoObjectActions, CertificateMixin[Certificate], Certi
         ),
         (
             _("X.509 Extensions"),
-            {
-                "fields": [
-                    "key_usage",
-                    "extended_key_usage",
-                    "tls_feature",
-                ]
-            },
+            {"fields": CERTIFICATE_EXTENSIONS},
         ),
     ]
     x509_fieldset_index = 1
 
+    @property
+    def ca_details_view_name(self) -> str:
+        """URL for the profiles view."""
+        return f"{self.model._meta.app_label}_{self.model._meta.verbose_name}_ca_details"
+
+    def ca_details_view(self, request: HttpRequest) -> JsonResponse:
+        """View for getting the extension values from the certificate authority."""
+        data: typing.Dict[int, typing.Dict[str, typing.Any]] = {}
+        for ca in CertificateAuthority.objects.usable():
+            if ca.key_exists is False:
+                continue
+
+            extensions = {
+                EXTENSION_KEYS[oid]: serialize_extension(ext)
+                for oid, ext in ca.extensions_for_certificate.items()
+            }
+
+            data[ca.pk] = {"extensions": extensions, "name": ca.name}
+
+        return JsonResponse(data)
+
     def has_add_permission(self, request: HttpRequest) -> bool:
         # Only grant add permissions if there is at least one useable CA
-        for ca in CertificateAuthority.objects.filter(enabled=True):
+        for ca in CertificateAuthority.objects.usable():
             if ca.key_exists:
                 return True
         return False
@@ -697,11 +701,18 @@ class CertificateAdmin(DjangoObjectActions, CertificateMixin[Certificate], Certi
             # resign the cert, so we add initial data from the original cert
 
             resign_obj = getattr(request, "_resign_obj")
-            san = resign_obj.subject_alternative_name
+            san = resign_obj.x509_extensions.get(ExtensionOID.SUBJECT_ALTERNATIVE_NAME)
             if san is None:
-                san = ("", False)
+                san_value = []
+                san_critical = EXTENSION_DEFAULT_CRITICAL[ExtensionOID.SUBJECT_ALTERNATIVE_NAME]
             else:
-                san = (",".join(san), False)
+                san_value = list(san.value)
+                san_critical = san.critical
+
+            # Since Django 4.1, tuples are no longer passed to a MultiWidgets decompress() method.  We must
+            # thus pass a three-tuple as initial value, each corresponding to the value of one of the widgets.
+            subject_alternative_name = (san_value, False, san_critical)
+
             algo = resign_obj.algorithm.__class__.__name__
 
             if resign_obj.profile:
@@ -712,17 +723,46 @@ class CertificateAdmin(DjangoObjectActions, CertificateMixin[Certificate], Certi
             data = {
                 "algorithm": algo,
                 "ca": resign_obj.ca,
-                "extended_key_usage": resign_obj.extended_key_usage,
-                "key_usage": resign_obj.key_usage,
                 "profile": profile,
                 "subject": resign_obj.subject,
-                "subject_alternative_name": san,
-                "tls_feature": resign_obj.tls_feature,
+                "subject_alternative_name": subject_alternative_name,
                 "watchers": resign_obj.watchers.all(),
             }
+
+            # Add values from editable extensions
+            extensions = resign_obj.x509_extensions
+            for key in CERTIFICATE_EXTENSIONS:
+                data[key] = extensions.get(EXTENSION_KEY_OIDS[key])
         else:
-            profile = ca_settings.CA_PROFILES[ca_settings.CA_DEFAULT_PROFILE]
-            data["subject"] = x509_name(profile.get("subject", tuple()))
+            # Form for a completely new certificate
+
+            ca = None
+            try:
+                ca = CertificateAuthority.objects.default()
+            except ImproperlyConfigured as ex:
+                log.error(ex)
+
+            # If the default CA is not usable, use the first one that we can use instead.
+            if ca is None or ca.key_exists is False:
+                for usable_ca in CertificateAuthority.objects.usable().order_by("-expires", "serial"):
+                    if usable_ca.key_exists:
+                        ca = usable_ca
+
+            # NOTE: This should not happen because if no CA is usable from the admin interface, the "add"
+            # button would not even show up.
+            if ca is None:  # pragma: no cover
+                raise ImproperlyConfigured("Cannot determine default CA.")
+
+            profile = profiles[ca_settings.CA_DEFAULT_PROFILE]
+            data["ca"] = ca
+            data["subject"] = profile.subject
+
+            data.update({EXTENSION_KEYS[oid]: ext for oid, ext in ca.extensions_for_certificate.items()})
+
+            for key in CERTIFICATE_EXTENSIONS:
+                ext = profile.extensions.get(EXTENSION_KEY_OIDS[key])
+                if ext is not None:
+                    data[key] = ext
 
         return data
 
@@ -735,6 +775,7 @@ class CertificateAdmin(DjangoObjectActions, CertificateMixin[Certificate], Certi
         extra_context = extra_context or {}
         extra_context["profiles_url"] = reverse(f"admin:{self.profiles_view_name}")
         extra_context["csr_details_url"] = reverse(f"admin:{self.csr_details_view_name}")
+        extra_context["ca_details_url"] = reverse(f"admin:{self.ca_details_view_name}")
         return super().add_view(
             request,
             form_url=form_url,
@@ -796,6 +837,14 @@ class CertificateAdmin(DjangoObjectActions, CertificateMixin[Certificate], Certi
                 "ajax/profiles", self.admin_site.admin_view(self.profiles_view), name=self.profiles_view_name
             ),
         )
+        urls.insert(
+            0,
+            path(
+                "ajax/ca-details/",
+                self.admin_site.admin_view(self.ca_details_view),
+                name=self.ca_details_view_name,
+            ),
+        )
 
         return urls
 
@@ -885,9 +934,13 @@ class CertificateAdmin(DjangoObjectActions, CertificateMixin[Certificate], Certi
             fieldsets[self.x509_fieldset_index][1]["fields"].remove("oid_2_5_29_17")
 
         if hasattr(request, "_resign_obj"):
-            return self.resign_fieldsets
+            fieldsets = copy.deepcopy(self.resign_fieldsets)
+            fieldsets[1][1]["description"] = render_to_string(["django_ca/admin/extensions-help.html"])
+            return fieldsets
         if obj is None:
-            return self.add_fieldsets
+            fieldsets = copy.deepcopy(self.add_fieldsets)
+            fieldsets[1][1]["description"] = render_to_string(["django_ca/admin/extensions-help.html"])
+            return fieldsets
 
         if obj.revoked is False:
             fieldsets[2][1]["classes"] = [
@@ -942,28 +995,62 @@ class CertificateAdmin(DjangoObjectActions, CertificateMixin[Certificate], Certi
 
             expires = datetime.combine(data["expires"], datetime.min.time())
 
-            extensions = {}
-            san, cn_in_san = data["subject_alternative_name"]
-            san = SubjectAlternativeName({"value": [e.strip() for e in san.split(",") if e.strip()]})
-            if san:
-                extensions[SubjectAlternativeName.key] = san
-            for key in [KeyUsage.key, ExtendedKeyUsage.key, TLSFeature.key]:
-                if data[key].value:
-                    extensions[key] = data[key]
-                else:
-                    extensions[key] = None
+            # Set Subject Alternative Name from form
+            extensions: typing.Dict[x509.ObjectIdentifier, x509.Extension[x509.ExtensionType]] = {}
+            subject_alternative_name, cn_in_san = data["subject_alternative_name"]
+            if subject_alternative_name:
+                extensions[ExtensionOID.SUBJECT_ALTERNATIVE_NAME] = subject_alternative_name
+
+            # Update extensions handled through the form
+            for key in CERTIFICATE_EXTENSIONS:
+                if data[key] is not None:
+                    extensions[EXTENSION_KEY_OIDS[key]] = data[key]
+
+            # Update extensions from the profile that cannot (yet) be changed in the web interface
+            for oid, ext in profile.extensions.items():
+                # If the extension is set to None by the profile, we do not add or modify it
+                # (A none value means that the extension is unset if the profile is selected by the user)
+                if ext is None:
+                    continue
+
+                # We currently only support the first distribution point, append others from profile
+                if (
+                    oid in (ExtensionOID.CRL_DISTRIBUTION_POINTS, ExtensionOID.FRESHEST_CRL)
+                    and oid in extensions
+                ):
+                    profile_ext = typing.cast(
+                        typing.Union[x509.CRLDistributionPoints, x509.FreshestCRL], ext.value
+                    )
+                    if len(profile_ext) > 1:  # pragma: no branch  # false positive
+                        form_ext = typing.cast(x509.Extension[CRLExtensionType], extensions[oid])
+                        dpoints = form_ext.value.__class__(list(form_ext.value) + profile_ext[1:])
+                        extensions[oid] = x509.Extension(
+                            oid=form_ext.oid, critical=form_ext.critical, value=dpoints
+                        )
+                    continue
+
+                if EXTENSION_KEYS[oid] in CERTIFICATE_EXTENSIONS:  # already handled in form
+                    continue
+                if oid == ExtensionOID.SUBJECT_ALTERNATIVE_NAME:  # already handled above
+                    continue
+                if oid == ExtensionOID.BASIC_CONSTRAINTS:  # set by default in profile, so ignore it
+                    continue
+
+                # Add any extension from the profile currently not changable in the web interface
+                extensions[oid] = ext
+
+            ca: CertificateAuthority = data["ca"]
 
             obj.profile = profile.name
             obj.update_certificate(
-                profile.create_cert(
-                    data["ca"],
+                ca.sign(
                     csr,
                     subject=data["subject"],
-                    expires=expires,
                     algorithm=data["algorithm"],
+                    expires=expires,
+                    extensions=extensions.values(),
                     cn_in_san=cn_in_san,
                     password=data["password"],
-                    extensions=extensions,
                 )
             )
             obj.save()
@@ -971,7 +1058,7 @@ class CertificateAdmin(DjangoObjectActions, CertificateMixin[Certificate], Certi
         else:
             obj.save()
 
-    class Media:  # pylint: disable=missing-class-docstring
+    class Media:
         css = {
             "all": (
                 "django_ca/admin/css/base.css",
