@@ -18,82 +18,63 @@
 import abc
 import binascii
 import collections.abc
-from typing import Any
-from typing import ClassVar
-from typing import Collection
-from typing import Generic
-from typing import Hashable
-from typing import Iterable
-from typing import Iterator
-from typing import List
-from typing import NoReturn
-from typing import Optional
-from typing import Set
-from typing import Tuple
-from typing import Type
-from typing import Union
-from typing import cast
-from typing import overload
+import warnings
+from typing import (
+    Any,
+    ClassVar,
+    Collection,
+    Generic,
+    Hashable,
+    Iterable,
+    Iterator,
+    List,
+    NoReturn,
+    Optional,
+    Set,
+    Tuple,
+    Type,
+    Union,
+    cast,
+    overload,
+)
 
 from cryptography import x509
-from cryptography.x509.certificate_transparency import LogEntryType
-from cryptography.x509.certificate_transparency import SignedCertificateTimestamp
+from cryptography.x509.certificate_transparency import LogEntryType, SignedCertificateTimestamp
 
-from ..typehints import AlternativeNameTypeVar
-from ..typehints import ExtensionType
-from ..typehints import ExtensionTypeTypeVar
-from ..typehints import IterableItem
-from ..typehints import ParsableDistributionPoint
-from ..typehints import ParsableExtension
-from ..typehints import ParsableGeneralName
-from ..typehints import ParsableGeneralNameList
-from ..typehints import ParsableItem
-from ..typehints import ParsableSignedCertificateTimestamp
-from ..typehints import ParsableValue
-from ..typehints import SerializedDistributionPoint
-from ..typehints import SerializedDistributionPoints
-from ..typehints import SerializedExtension
-from ..typehints import SerializedItem
-from ..typehints import SerializedNullExtension
-from ..typehints import SerializedSignedCertificateTimestamp
-from ..typehints import SerializedSortableItem
-from ..typehints import SerializedValue
-from ..typehints import SignedCertificateTimestampsBaseTypeVar
-from ..typehints import UnrecognizedExtensionType
-from ..utils import GeneralNameList
-from ..utils import format_general_name
+from ..deprecation import RemovedInDjangoCA124Warning
+from ..typehints import (
+    AlternativeNameTypeVar,
+    ExtensionType,
+    ExtensionTypeTypeVar,
+    IterableItem,
+    ParsableDistributionPoint,
+    ParsableExtension,
+    ParsableGeneralName,
+    ParsableGeneralNameList,
+    ParsableItem,
+    ParsableSignedCertificateTimestamp,
+    ParsableValue,
+    SerializedDistributionPoint,
+    SerializedDistributionPoints,
+    SerializedExtension,
+    SerializedItem,
+    SerializedNullExtension,
+    SerializedSignedCertificateTimestamp,
+    SerializedSortableItem,
+    SerializedValue,
+    SignedCertificateTimestampsBaseTypeVar,
+    UnrecognizedExtensionType,
+)
+from ..utils import GeneralNameList, format_general_name
+from .text import extension_as_text
 from .utils import DistributionPoint
-from .utils import extension_as_text
 
 
 class Extension(Generic[ExtensionTypeTypeVar, ParsableValue, SerializedValue], metaclass=abc.ABCMeta):
     """Convenience class to handle X509 Extensions.
 
-    The value is a ``dict`` as used by the :ref:`CA_PROFILES <settings-ca-profiles>` setting::
-
-        >>> KeyUsage({'value': ['keyAgreement', 'keyEncipherment']})
-        <KeyUsage: ['keyAgreement', 'keyEncipherment'], critical=True>
-        >>> KeyUsage({'critical': False, 'value': ['key_agreement', 'key_encipherment']})
-        <KeyUsage: ['keyAgreement', 'keyEncipherment'], critical=False>
-
-    ... but can also use a subclass of :py:class:`~cg:cryptography.x509.ExtensionType`
-    from ``cryptography``::
-
-        >>> from cryptography import x509
-        >>> cg_ext = x509.extensions.Extension(
-        ...    oid=ExtensionOID.EXTENDED_KEY_USAGE,
-        ...    critical=False,
-        ...    value=x509.ExtendedKeyUsage([ExtendedKeyUsageOID.SERVER_AUTH])
-        ... )
-        >>> ExtendedKeyUsage(cg_ext)
-        <ExtendedKeyUsage: ['serverAuth'], critical=False>
-        >>> ExtendedKeyUsage({'value': ['serverAuth']})
-        <ExtendedKeyUsage: ['serverAuth'], critical=False>
-
-
-    .. versionchanged:: 1.18.0
-
-       This class is now an abstract base class.
+    The value is a ``dict`` as used by the :ref:`CA_PROFILES <settings-ca-profiles>` setting, but can also use
+    a subclass of :py:class:`~cg:cryptography.x509.ExtensionType` from ``cryptography``.
 
     Parameters
     ----------
@@ -128,6 +109,7 @@ class Extension(Generic[ExtensionTypeTypeVar, ParsableValue, SerializedValue], m
     def __init__(
         self, value: Optional[Union["x509.Extension[ExtensionTypeTypeVar]", ParsableExtension]] = None
     ) -> None:
+        self.deprecate()
         if value is None:
             value = {}
 
@@ -144,6 +126,14 @@ class Extension(Generic[ExtensionTypeTypeVar, ParsableValue, SerializedValue], m
         if not isinstance(self.critical, bool):
             raise ValueError(f"{self.critical}: Invalid critical value passed")
 
+    def deprecate(self) -> None:
+        cls_path = f"{self.__class__.__module__}.{self.__class__.__name__}"
+        warnings.warn(
+            f"{cls_path} is deprecated and will be removed in django-ca 1.24.0.",
+            RemovedInDjangoCA124Warning,
+            stacklevel=3,
+        )
+
     def __eq__(self, other: Any) -> bool:
         return (
             isinstance(other, type(self))
@@ -185,15 +175,7 @@ class Extension(Generic[ExtensionTypeTypeVar, ParsableValue, SerializedValue], m
         Implementing classes are expected to implement this function."""
 
     def for_builder(self) -> Tuple[ExtensionTypeTypeVar, bool]:
-        """Return a tuple suitable for a :py:class:`~cg:cryptography.x509.CertificateBuilder`.
-
-        Example::
-
-            >>> ext = KeyUsage({'value': ['keyAgreement', 'keyEncipherment']})
-            >>> builder = x509.CertificateBuilder()
-            >>> builder.add_extension(*ext.for_builder())  # doctest: +ELLIPSIS
-            <cryptography.x509.base.CertificateBuilder object at ...>
-        """
+        """Return a tuple suitable for a :py:class:`~cg:cryptography.x509.CertificateBuilder`."""
         return self.extension_type, self.critical
 
     @abc.abstractmethod
@@ -228,14 +210,7 @@ class Extension(Generic[ExtensionTypeTypeVar, ParsableValue, SerializedValue], m
         Implementing classes are expected to implement this function."""
 
     def serialize(self) -> SerializedExtension:
-        """Serialize this extension to a string in a way that it can be passed to a constructor again.
-
-        For example, this should always be True::
-
-            >>> ku = KeyUsage({'value': ['keyAgreement', 'keyEncipherment']})
-            >>> ku == KeyUsage(ku.serialize())
-            True
-        """
+        """Serialize this extension to a string in a way that it can be passed to a constructor again."""
 
         return {
             "critical": self.critical,
@@ -259,6 +234,7 @@ class UnrecognizedExtension(Extension[x509.UnrecognizedExtension, None, None]):
 
     # pylint: disable-next=unused-argument
     def __init__(self, value: UnrecognizedExtensionType, name: str = "", error: str = ""):
+        self.deprecate()
         if not isinstance(value, x509.Extension):
             raise TypeError("Value must be a x509.Extension instance")
         if not isinstance(value.value, x509.UnrecognizedExtension):
@@ -294,21 +270,11 @@ class NullExtension(Extension[ExtensionTypeTypeVar, None, None]):
 
        This class is now an abstract base class.
 
-    Some extensions, like :py:class:`~django_ca.extensions.OCSPNoCheck` or
-    :py:class:`~django_ca.extensions.PrecertPoison` do not encode any information, but the presence of the
-    extension itself carries meaning.
+    Some extensions, like ``django_ca.extensions.OCSPNoCheck`` or ``django_ca.extensions.PrecertPoison`` do
+    not encode any information, but the presence of the extension itself carries meaning.
 
     Extensions using this base class will ignore any ``"value"`` key in their dict, only the ``"critical"``
-    key is relevant:
-
-        >>> OCSPNoCheck()
-        <OCSPNoCheck: critical=False>
-        >>> OCSPNoCheck({'critical': True})
-        <OCSPNoCheck: critical=True>
-        >>> OCSPNoCheck({'critical': True})
-        <OCSPNoCheck: critical=True>
-        >>> OCSPNoCheck(x509.extensions.Extension(oid=ExtensionOID.OCSP_NO_CHECK, critical=True, value=None))
-        <OCSPNoCheck: critical=True>
+    key is relevant.
     """
 
     ext_class: Type[ExtensionTypeTypeVar]
@@ -329,7 +295,7 @@ class NullExtension(Extension[ExtensionTypeTypeVar, None, None]):
 
     @property
     def extension_type(self) -> ExtensionTypeTypeVar:
-        return self.ext_class()  # pylint: disable=no-member; concrete classes are expected to set this
+        return self.ext_class()
 
     def from_extension(self, value: ExtensionTypeTypeVar) -> None:
         pass
@@ -352,23 +318,13 @@ class IterableExtension(
 ):
     """Base class for iterable extensions.
 
-    Extensions of this class can be used just like any other iterable, e.g.:
-
-        >>> e = KeyUsage({'value': ['cRLSign'], 'critical': True})
-        >>> 'cRLSign' in e
-        True
-        >>> len(e)
-        1
-        >>> for val in e:
-        ...     print(val)
-        cRLSign
+    Extensions of this class can be used just like any other iterable.
     """
 
-    # pylint: disable=abstract-method; class is itself a base class
     value: Collection[IterableItem]
 
     def __contains__(self, value: ParsableItem) -> bool:
-        return self.parse_value(value) in self.value  # pylint: disable=unsupported-membership-test
+        return self.parse_value(value) in self.value
 
     def __eq__(self, other: Any) -> bool:
         return isinstance(other, type(self)) and self.critical == other.critical and self.value == other.value
@@ -402,7 +358,7 @@ class IterableExtension(
     def serialize_value(self) -> List[SerializedItem]:
         """Serialize the whole iterable contained in this extension."""
 
-        return [self.serialize_item(v) for v in self.value]  # pylint: disable=not-an-iterable
+        return [self.serialize_item(v) for v in self.value]
 
     def serialize_item(self, value: IterableItem) -> SerializedItem:
         """Serialize a single item in the iterable contained in this extension."""
@@ -497,21 +453,9 @@ class OrderedSetExtension(
 ):
     """Base class for extensions that contain a set of values.
 
-    .. versionchanged:: 1.18.0
-
-       This class is now an abstract base class.
-
     For reproducibility, any serialization will always sort the values contained in this extension.
 
-    Extensions derived from this class can be used like a normal set, for example:
-
-        >>> e = KeyUsage({'value': {'cRLSign', }})
-        >>> e.add('keyAgreement')
-        >>> e
-        <KeyUsage: ['cRLSign', 'keyAgreement'], critical=True>
-        >>> e -= {'keyAgreement', }
-        >>> e
-        <KeyUsage: ['cRLSign'], critical=True>
+    Extensions derived from this class can be used like a normal set.
     """
 
     # pylint: disable=abstract-method; class is itself a base class
@@ -587,7 +531,6 @@ class OrderedSetExtension(
         return set(self.parse_value(i) for i in iterable)
 
     def from_dict(self, value: Iterable[ParsableItem]) -> None:
-        # pylint: disable=attribute-defined-outside-init; https://github.com/PyCQA/pylint/issues/3605
         self.value = self.parse_iterable(value)
 
     def serialize_value(self) -> List[SerializedSortableItem]:
@@ -671,14 +614,7 @@ class AlternativeNameExtension(
 ):
     """Base class for extensions that contain a list of general names.
 
-    This class also allows you to pass :py:class:`~cg:cryptography.x509.GeneralName` instances::
-
-        >>> san = SubjectAlternativeName({'value': [x509.DNSName('example.com'), 'example.net']})
-        >>> san
-        <SubjectAlternativeName: ['DNS:example.com', 'DNS:example.net'], critical=False>
-        >>> 'example.com' in san, 'DNS:example.com' in san, x509.DNSName('example.com') in san
-        (True, True, True)
-
+    This class also allows you to pass :py:class:`~cg:cryptography.x509.GeneralName` instances.
     """
 
     # pylint: disable=abstract-method; class is itself abstract
@@ -707,8 +643,8 @@ class CRLDistributionPointsBase(
     Generic[ExtensionTypeTypeVar],
     metaclass=abc.ABCMeta,
 ):
-    """Base class for :py:class:`~django_ca.extensions.CRLDistributionPoints` and
-    :py:class:`~django_ca.extensions.FreshestCRL`.
+    """Base class for ``django_ca.extensions.CRLDistributionPoints`` and
+    ``django_ca.extensions.FreshestCRL``.
     """
 
     def __hash__(self) -> int:
@@ -795,7 +731,7 @@ class SignedCertificateTimestampsBase(
     def count(self, value: ParsableSignedCertificateTimestamp) -> int:
         if isinstance(value, dict):
             return self.serialize_value().count(value)
-        return self.value.count(value)  # pylint: disable=protected-access
+        return self.value.count(value)
 
     def extend(self, iterable):  # type: ignore
         raise NotImplementedError
