@@ -16,44 +16,40 @@
 The classes in this module wrap cryptography extensions, but allow adding/removing values, creating extensions
 in a more pythonic manner and provide access functions."""
 
-from typing import ClassVar
-from typing import Optional
-from typing import Set
-from typing import Tuple
-from typing import Union
+from typing import ClassVar, Optional, Set, Tuple, Union
 
 from cryptography import x509
 from cryptography.x509 import TLSFeatureType
-from cryptography.x509.oid import AuthorityInformationAccessOID
-from cryptography.x509.oid import ExtensionOID
+from cryptography.x509.oid import AuthorityInformationAccessOID, ExtensionOID
 
-from ..typehints import ParsableAuthorityInformationAccess
-from ..typehints import ParsableAuthorityKeyIdentifier
-from ..typehints import ParsableBasicConstraints
-from ..typehints import ParsableExtension
-from ..typehints import ParsableGeneralNameList
-from ..typehints import ParsableNameConstraints
-from ..typehints import ParsablePolicyConstraints
-from ..typehints import ParsablePolicyInformation
-from ..typehints import ParsableSubjectKeyIdentifier
-from ..typehints import SerializedAuthorityInformationAccess
-from ..typehints import SerializedAuthorityKeyIdentifier
-from ..typehints import SerializedBasicConstraints
-from ..typehints import SerializedNameConstraints
-from ..typehints import SerializedPolicyConstraints
-from ..typehints import SerializedPolicyInformation
-from ..utils import GeneralNameList
-from ..utils import bytes_to_hex
-from ..utils import hex_to_bytes
-from .base import AlternativeNameExtension
-from .base import CRLDistributionPointsBase
-from .base import Extension
-from .base import ListExtension
-from .base import NullExtension
-from .base import OrderedSetExtension
-from .base import SignedCertificateTimestampsBase
-from .utils import EXTENDED_KEY_USAGE_NAMES
-from .utils import KEY_USAGE_NAMES
+from ..constants import EXTENDED_KEY_USAGE_NAMES, KEY_USAGE_NAMES
+from ..typehints import (
+    ParsableAuthorityInformationAccess,
+    ParsableAuthorityKeyIdentifier,
+    ParsableBasicConstraints,
+    ParsableExtension,
+    ParsableGeneralNameList,
+    ParsableNameConstraints,
+    ParsablePolicyConstraints,
+    ParsablePolicyInformation,
+    ParsableSubjectKeyIdentifier,
+    SerializedAuthorityInformationAccess,
+    SerializedAuthorityKeyIdentifier,
+    SerializedBasicConstraints,
+    SerializedNameConstraints,
+    SerializedPolicyConstraints,
+    SerializedPolicyInformation,
+)
+from ..utils import GeneralNameList, bytes_to_hex, hex_to_bytes
+from .base import (
+    AlternativeNameExtension,
+    CRLDistributionPointsBase,
+    Extension,
+    ListExtension,
+    NullExtension,
+    OrderedSetExtension,
+    SignedCertificateTimestampsBase,
+)
 from .utils import PolicyInformation
 
 # Placeholder until we fill in something good
@@ -122,7 +118,6 @@ class AuthorityInformationAccess(
 
     @property
     def extension_type(self) -> x509.AuthorityInformationAccess:
-        # pylint: disable=not-an-iterable; pylint does not detect GeneralNameList as iterable
         descs = [x509.AccessDescription(AuthorityInformationAccessOID.CA_ISSUERS, v) for v in self._issuers]
         descs += [x509.AccessDescription(AuthorityInformationAccessOID.OCSP, v) for v in self._ocsp]
         return x509.AuthorityInformationAccess(descriptions=descs)
@@ -205,6 +200,7 @@ class AuthorityKeyIdentifier(
         ] = None,
     ) -> None:
         if isinstance(value, SubjectKeyIdentifier):
+            self.deprecate()
             self.critical = self.default_critical
             self.from_subject_key_identifier(value)
             self._test_value()
@@ -244,7 +240,10 @@ class AuthorityKeyIdentifier(
         else:
             self.key_identifier = self.parse_keyid(value.get("key_identifier"))
             self.authority_cert_issuer = GeneralNameList(value.get("authority_cert_issuer"))
-            self.authority_cert_serial_number = value.get("authority_cert_serial_number")
+            serial_number = value.get("authority_cert_serial_number")
+            if isinstance(serial_number, str):
+                serial_number = int(serial_number)
+            self.authority_cert_serial_number = serial_number
 
     def from_extension(self, value: x509.AuthorityKeyIdentifier) -> None:
         self.key_identifier = value.key_identifier
@@ -253,7 +252,6 @@ class AuthorityKeyIdentifier(
 
     def from_subject_key_identifier(self, ext: "SubjectKeyIdentifier") -> None:
         """Create an extension based on SubjectKeyIdentifier extension."""
-        # pylint: disable=attribute-defined-outside-init; func is designed to be called by init
         self.key_identifier = ext.value
         self.authority_cert_issuer = GeneralNameList()
         self.authority_cert_serial_number = None
@@ -351,7 +349,7 @@ class CRLDistributionPoints(CRLDistributionPointsBase[x509.CRLDistributionPoints
     This extension identifies where a client can retrieve a Certificate Revocation List (CRL).
 
     The value passed to this extension should be a ``list`` of
-    :py:class:`~django_ca.extensions.utils.DistributionPoint` instances. Naturally, you can also pass those in
+    ``django_ca.extensions.utils.DistributionPoint`` instances. Naturally, you can also pass those in
     serialized form::
 
         >>> CRLDistributionPoints({'value': [
@@ -387,7 +385,7 @@ class CertificatePolicies(
     """Class representing a Certificate Policies extension.
 
     The value passed to this extension should be a ``list`` of
-    :py:class:`~django_ca.extensions.utils.PolicyInformation` instances. Naturally, you can also pass those in
+    ``django_ca.extensions.utils.PolicyInformation`` instances. Naturally, you can also pass those in
     serialized form::
 
         >>> CertificatePolicies({'value': [{
@@ -436,7 +434,7 @@ class CertificatePolicies(
 class FreshestCRL(CRLDistributionPointsBase[x509.FreshestCRL]):
     """Class representing a FreshestCRL extension.
 
-    This extension handles identically to the :py:class:`~django_ca.extensions.CRLDistributionPoints`
+    This extension handles identically to the ``django_ca.extensions.CRLDistributionPoints``
     extension::
 
         >>> FreshestCRL({'value': [
@@ -564,13 +562,12 @@ class KeyUsage(OrderedSetExtension[x509.KeyUsage, str, str, str]):
         raise ValueError(f"Unknown value: {value}")  # pragma: no cover  # function returns/raises before
 
     def serialize_item(self, value: str) -> str:
-        return self._CRYPTOGRAPHY_MAPPING_REVERSED[value]
+        return value
 
 
 class ExtendedKeyUsage(
     OrderedSetExtension[x509.ExtendedKeyUsage, Union[x509.ObjectIdentifier, str], str, x509.ObjectIdentifier]
 ):
-    # class ExtendedKeyUsage():
     """Class representing a ExtendedKeyUsage extension."""
 
     key = "extended_key_usage"
@@ -592,6 +589,7 @@ class ExtendedKeyUsage(
         ("emailProtection", "E-mail Protection (S/MIME)"),
         ("timeStamping", "Trusted Timestamping"),
         ("OCSPSigning", "OCSP Signing"),
+        ("certificateTransparency", "Certificate Transparency"),
         ("smartcardLogon", "Smart card logon"),
         ("msKDC", "Kerberos Domain Controller"),
         ("ipsecEndSystem", "IPSec EndSystem"),
@@ -659,6 +657,7 @@ class InhibitAnyPolicy(Extension[x509.InhibitAnyPolicy, int, int]):
         value: Optional[Union["x509.Extension[x509.InhibitAnyPolicy]", ParsableExtension, int]] = None,
     ) -> None:
         if isinstance(value, int):
+            self.deprecate()
             self.critical = self.default_critical
             self.skip_certs = value
             self._test_value()
@@ -778,7 +777,7 @@ class NameConstraints(Extension[x509.NameConstraints, ParsableNameConstraints, S
 
     Unlike most other extensions, this extension does not accept a string as value, but you can pass a list
     containing the permitted/excluded subtrees as lists. Similar to
-    :py:class:`~django_ca.extensions.SubjectAlternativeName`, you can pass both strings or instances of
+    ``django_ca.extensions.SubjectAlternativeName``, you can pass both strings or instances of
     :py:class:`~cg:cryptography.x509.GeneralName`::
 
         >>> NameConstraints({'value': {
@@ -862,10 +861,12 @@ class NameConstraints(Extension[x509.NameConstraints, ParsableNameConstraints, S
         self._permitted = value
 
     def serialize_value(self) -> SerializedNameConstraints:
-        return {
-            "permitted": self._permitted.serialize(),
-            "excluded": self._excluded.serialize(),
-        }
+        serialized: SerializedNameConstraints = {}
+        if self.permitted:
+            serialized["permitted"] = self._permitted.serialize()
+        if self.excluded:
+            serialized["excluded"] = self._excluded.serialize()
+        return serialized
 
     # Do not use @property for read/write properties where the setter has a different type
     #   https://github.com/python/mypy/issues/3004
@@ -942,7 +943,7 @@ class PrecertificateSignedCertificateTimestamps(
 
     This class cannot be instantiated by anything but
     :py:class:`cg:cryptography.x509.PrecertificateSignedCertificateTimestamps`. Please see
-    :py:class:`~django_ca.extensions.base.SignedCertificateTimestampsBase` for more information.
+    ``django_ca.extensions.base.SignedCertificateTimestampsBase`` for more information.
     """
 
     # pylint: disable=abstract-method; methods that raise NotImplemented are recognized as abstract
@@ -1020,6 +1021,7 @@ class SubjectKeyIdentifier(Extension[x509.SubjectKeyIdentifier, ParsableSubjectK
         ] = None,
     ) -> None:
         if isinstance(value, x509.SubjectKeyIdentifier):
+            self.deprecate()
             self.critical = self.default_critical
             self.value = value.digest
         else:
@@ -1053,8 +1055,8 @@ class SubjectKeyIdentifier(Extension[x509.SubjectKeyIdentifier, ParsableSubjectK
 class TLSFeature(OrderedSetExtension[x509.TLSFeature, Union[TLSFeatureType, str], str, TLSFeatureType]):
     """Class representing a TLSFeature extension.
 
-    As a :py:class:`~django_ca.extensions.base.OrderedSetExtension`, this extension handles much like it's
-    other sister extensions::
+    As a ``django_ca.extensions.base.OrderedSetExtension``, this extension handles much like it's other sister
+    extensions::
 
         >>> TLSFeature({'value': ['OCSPMustStaple']})
         <TLSFeature: ['OCSPMustStaple'], critical=False>
@@ -1077,10 +1079,15 @@ class TLSFeature(OrderedSetExtension[x509.TLSFeature, Union[TLSFeatureType, str]
     CRYPTOGRAPHY_MAPPING = {
         # https://tools.ietf.org/html/rfc6066.html:
         "OCSPMustStaple": TLSFeatureType.status_request,
+        "status_request": TLSFeatureType.status_request,
         # https://tools.ietf.org/html/rfc6961.html (not commonly used):
         "MultipleCertStatusRequest": TLSFeatureType.status_request_v2,
+        "status_request_v2": TLSFeatureType.status_request_v2,
+    }
+    SERIALIZER_MAPPING = {
+        TLSFeatureType.status_request: "OCSPMustStaple",
+        TLSFeatureType.status_request_v2: "MultipleCertStatusRequest",
     }
-    _CRYPTOGRAPHY_MAPPING_REVERSED = {v: k for k, v in CRYPTOGRAPHY_MAPPING.items()}
     KNOWN_PARAMETERS = sorted(CRYPTOGRAPHY_MAPPING)
     """Known values that can be passed to this extension."""
 
@@ -1092,8 +1099,13 @@ class TLSFeature(OrderedSetExtension[x509.TLSFeature, Union[TLSFeatureType, str]
         # call serialize_item() to ensure consistent sort order
         return x509.TLSFeature(sorted(self.value, key=self.serialize_item))
 
+    def repr_value(self) -> str:
+        values = [f"'{self.SERIALIZER_MAPPING[value]}'" for value in self.value]
+        joined = ", ".join(sorted(values))
+        return f"[{joined}]"
+
     def serialize_item(self, value: TLSFeatureType) -> str:
-        return self._CRYPTOGRAPHY_MAPPING_REVERSED[value]
+        return str(value.name)
 
     def parse_value(self, value: Union[TLSFeatureType, str]) -> TLSFeatureType:
         if isinstance(value, TLSFeatureType):
