@@ -20,9 +20,10 @@ import typing
 
 from cryptography.hazmat.primitives.serialization import Encoding
 
-from django.core.management.base import CommandError
-from django.core.management.base import CommandParser
+from django.core.management.base import CommandError, CommandParser
 
+from ...models import CertificateAuthority
+from ...typehints import Literal
 from ..base import BinaryCommand
 
 
@@ -43,42 +44,60 @@ class Command(BinaryCommand):
         parser.add_argument(
             "path", nargs="?", default="-", help='Path for the output file. Use "-" for stdout.'
         )
-        parser.add_argument(
-            "--ca-crl",
-            action="store_true",
-            default=False,
-            help="*DEPRECATED:* Use --scope=ca instead. Generate the CRL for revoked child CAs.",
-        )
         parser.add_argument(
             "-s",
             "--scope",
             choices=["ca", "user", "attribute"],
             help="Limit the scope for the CRL (default: %(default)s).",
         )
+
+        include_idp_group = parser.add_mutually_exclusive_group()
+        include_idp_group.add_argument(
+            "--include-issuing-distribution-point",
+            action="store_true",
+            default=None,
+            help="Force inclusion of an IssuingDistributionPoint extension.",
+        )
+        include_idp_group.add_argument(
+            "--exclude-issuing-distribution-point",
+            action="store_false",
+            dest="include_issuing_distribution_point",
+            help="Force exclusion of an IssuingDistributionPoint extension.",
+        )
         self.add_algorithm(parser)
         self.add_format(parser)
         self.add_ca(parser, allow_disabled=True)
         self.add_password(parser)
         super().add_arguments(parser)
 
-    def handle(self, path: str, encoding: Encoding, **options: typing.Any) -> None:  # type: ignore[override]
-        if options["ca_crl"]:
-            self.stderr.write(self.style.WARNING("WARNING: --ca-crl is deprecated, use --scope=ca instead."))
-            options["scope"] = "ca"
+    def handle(
+        self,
+        path: str,
+        ca: CertificateAuthority,
+        encoding: Encoding,
+        scope: typing.Optional[Literal["ca", "user", "attribute"]],
+        include_issuing_distribution_point: typing.Optional[bool],
+        **options: typing.Any
+    ) -> None:
+        # Catch this case early so that we can give a better error message.
+        if include_issuing_distribution_point is True and ca.parent is None and scope is None:
+            raise CommandError(
+                "Cannot add IssuingDistributionPoint extension to CRLs with no scope for root CAs."
+            )
 
         kwargs = {
             "expires": options["expires"],
             "algorithm": options["algorithm"],
             "password": options["password"],
-            "scope": options["scope"],
         }
 
         # See if we can work with the private key
-        ca = options["ca"]
         self.test_private_key(ca, options["password"])
 
         try:
-            crl = ca.get_crl(**kwargs).public_bytes(encoding)
+            crl = ca.get_crl(
+                include_issuing_distribution_point=include_issuing_distribution_point, scope=scope, **kwargs
+            ).public_bytes(encoding)
         except Exception as ex:
             # Note: all parameters are already sanitized by parser actions
             raise CommandError(ex) from ex
