@@ -22,12 +22,10 @@ import typing
 
 from cryptography import x509
 from cryptography.hazmat.primitives import serialization
-from cryptography.hazmat.primitives.serialization import Encoding
-from cryptography.hazmat.primitives.serialization import PrivateFormat
+from cryptography.hazmat.primitives.serialization import Encoding, PrivateFormat
 
 from django.core.files.base import ContentFile
-from django.core.management.base import CommandError
-from django.core.management.base import CommandParser
+from django.core.management.base import CommandError, CommandParser
 
 from ... import ca_settings
 from ...models import CertificateAuthority
@@ -73,7 +71,7 @@ Note that the private key will be copied to the directory configured by the CA_D
             "pem", help="Path to the public key (PEM or DER format).", type=argparse.FileType("rb")
         )
 
-    def handle(  # type: ignore[override]
+    def handle(
         self,
         name: str,
         key: typing.BinaryIO,
