@@ -26,25 +26,16 @@ from cryptography.hazmat.primitives import hashes
 from cryptography.hazmat.primitives.asymmetric import ec
 from cryptography.x509.oid import NameOID
 
-from django.core.management.base import CommandError
-from django.core.management.base import CommandParser
+from django.core.management.base import CommandError, CommandParser
 from django.utils import timezone
 
 from ... import ca_settings
-from ...extensions import OID_DEFAULT_CRITICAL
-from ...extensions import OID_TO_KEY
+from ...constants import EXTENSION_KEYS
 from ...models import CertificateAuthority
-from ...tasks import cache_crl
-from ...tasks import generate_ocsp_key
-from ...tasks import run_task
+from ...tasks import cache_crl, generate_ocsp_key, run_task
 from ...typehints import ParsableKeyType
-from ...utils import parse_general_name
-from ...utils import sort_name
-from ..actions import ExpiresAction
-from ..actions import MultipleURLAction
-from ..actions import NameAction
-from ..actions import PasswordAction
-from ..actions import URLAction
+from ...utils import parse_general_name, sort_name
+from ..actions import ExpiresAction, MultipleURLAction, NameAction, PasswordAction, URLAction
 from ..base import BaseCommand
 from ..mixins import CertificateAuthorityDetailMixin
 
@@ -178,7 +169,7 @@ class Command(CertificateAuthorityDetailMixin, BaseCommand):
 
         self.add_ca_args(parser)
 
-    def handle(  # type: ignore[override] # pylint: disable=too-many-arguments,too-many-locals
+    def handle(  # pylint: disable=too-many-arguments,too-many-locals
         self,
         name: str,
         subject: x509.Name,
@@ -233,13 +224,7 @@ class Command(CertificateAuthorityDetailMixin, BaseCommand):
 
         subject = sort_name(subject)
 
-        issuer_alternative_name = options[OID_TO_KEY[x509.IssuerAlternativeName.oid]]
-        if issuer_alternative_name is not None:
-            issuer_alternative_name = x509.Extension(
-                oid=x509.IssuerAlternativeName.oid,
-                critical=OID_DEFAULT_CRITICAL[x509.IssuerAlternativeName.oid],
-                value=issuer_alternative_name,
-            )
+        issuer_alternative_name = options[EXTENSION_KEYS[x509.IssuerAlternativeName.oid]]
 
         kwargs = {}
         for opt in ["path", "default_hostname"]:
