@@ -22,13 +22,11 @@ from datetime import timedelta
 from cryptography.hazmat.primitives import hashes
 from cryptography.hazmat.primitives.asymmetric import ec
 
-from django.core.management.base import CommandError
-from django.core.management.base import CommandParser
+from django.core.management.base import CommandError, CommandParser
 
 from ... import ca_settings
 from ...models import CertificateAuthority
-from ...tasks import generate_ocsp_key
-from ...tasks import run_task
+from ...tasks import generate_ocsp_key, run_task
 from ...typehints import ParsableKeyType
 from ...utils import add_colons
 from ..actions import ExpiresAction
@@ -64,7 +62,7 @@ class Command(BaseCommand):  # pylint: disable=missing-class-docstring
             parser, 'Override the profile used for generating the certificate. By default, "ocsp" is used.'
         )
 
-    def handle(  # type: ignore[override]
+    def handle(
         self,
         serials: typing.Iterable[str],
         profile: typing.Optional[str],
