@@ -20,25 +20,16 @@ import typing
 from datetime import timedelta
 
 from cryptography import x509
+from cryptography.x509.oid import ExtensionOID, NameOID
 
-from django.core.management.base import CommandError
-from django.core.management.base import CommandParser
+from django.core.management.base import CommandError, CommandParser
 
 from ... import ca_settings
-from ...extensions import OID_DEFAULT_CRITICAL
-from ...extensions import OID_TO_KEY
-from ...extensions import ExtendedKeyUsage
-from ...extensions import KeyUsage
-from ...extensions import SubjectAlternativeName
-from ...extensions import TLSFeature
+from ...constants import EXTENSION_KEYS
 from ...management.actions import CertificateAction
 from ...management.base import BaseSignCommand
-from ...models import Certificate
-from ...models import CertificateAuthority
-from ...models import Watcher
-from ...profiles import Profile
-from ...profiles import profiles
-from ...subject import Subject
+from ...models import Certificate, CertificateAuthority, Watcher
+from ...profiles import Profile, profiles
 
 
 class Command(BaseSignCommand):  # pylint: disable=missing-class-docstring
@@ -70,11 +61,11 @@ default profile, currently {ca_settings.CA_DEFAULT_PROFILE}."""
                 f'Profile "{cert.profile}" for original certificate is no longer defined, please set one via the command line.'  # NOQA: E501
             )
 
-    def handle(  # type: ignore[override]
+    def handle(
         self,
         cert: Certificate,
         ca: typing.Optional[CertificateAuthority],
-        subject: typing.Optional[Subject],
+        subject: typing.Optional[x509.Name],
         expires: typing.Optional[timedelta],
         watch: typing.List[str],
         password: typing.Optional[bytes],
@@ -94,51 +85,46 @@ default profile, currently {ca_settings.CA_DEFAULT_PROFILE}."""
             watchers = list(cert.watchers.all())
 
         if subject is None:
-            subject = Subject(cert.subject)
+            subject = cert.subject
 
-        if not options[KeyUsage.key]:
-            key_usage = cert.key_usage
+        if not options[EXTENSION_KEYS[ExtensionOID.KEY_USAGE]]:
+            key_usage = cert.x509_extensions.get(ExtensionOID.KEY_USAGE)
         else:
-            key_usage = options[KeyUsage.key]
+            key_usage = options[EXTENSION_KEYS[ExtensionOID.KEY_USAGE]]
 
-        if not options[ExtendedKeyUsage.key]:
-            ext_key_usage = cert.extended_key_usage
+        if not options[EXTENSION_KEYS[ExtensionOID.EXTENDED_KEY_USAGE]]:
+            ext_key_usage = cert.x509_extensions.get(ExtensionOID.EXTENDED_KEY_USAGE)
         else:
-            ext_key_usage = options[ExtendedKeyUsage.key]
+            ext_key_usage = options[EXTENSION_KEYS[ExtensionOID.EXTENDED_KEY_USAGE]]
 
-        if not options[TLSFeature.key]:
-            tls_feature = cert.tls_feature
+        if not options[EXTENSION_KEYS[ExtensionOID.TLS_FEATURE]]:
+            tls_feature = cert.x509_extensions.get(ExtensionOID.TLS_FEATURE)
         else:
-            tls_feature = options[TLSFeature.key]
+            tls_feature = options[EXTENSION_KEYS[ExtensionOID.TLS_FEATURE]]
 
         kwargs = {
             "algorithm": options["algorithm"],
-            "extensions": {},
+            "extensions": [],
             "password": password,
-            "subject": subject,
             "cn_in_san": False,  # we already copy the SAN/CN from the original cert
         }
 
         for ext in [key_usage, ext_key_usage, tls_feature]:
             if ext is not None:
-                kwargs["extensions"][ext.key] = ext
+                kwargs["extensions"].append(ext)
 
-        if not options[OID_TO_KEY[SubjectAlternativeName.oid]]:
-            san = cert._x509_extensions.get(SubjectAlternativeName.oid)  # pylint: disable=protected-access
+        if not options[EXTENSION_KEYS[ExtensionOID.SUBJECT_ALTERNATIVE_NAME]]:
+            san = cert.x509_extensions.get(ExtensionOID.SUBJECT_ALTERNATIVE_NAME)
         else:
-            san = x509.Extension(
-                oid=SubjectAlternativeName.oid,
-                critical=OID_DEFAULT_CRITICAL[SubjectAlternativeName.oid],
-                value=options[OID_TO_KEY[SubjectAlternativeName.oid]],
-            )
-        kwargs["extensions"][OID_TO_KEY[SubjectAlternativeName.oid]] = san
+            san = options[EXTENSION_KEYS[ExtensionOID.SUBJECT_ALTERNATIVE_NAME]]
+        kwargs["extensions"].append(san)
 
-        if "CN" not in kwargs["subject"] and not san:
+        if not subject.get_attributes_for_oid(NameOID.COMMON_NAME) and not san:
             raise CommandError("Must give at least a CN in --subject or one or more --alt arguments.")
 
         try:
             cert = Certificate.objects.create_cert(
-                ca=ca, csr=cert.csr.loaded, expires=expires, profile=profile_obj, **kwargs
+                ca=ca, csr=cert.csr.loaded, profile=profile_obj, expires=expires, subject=subject, **kwargs
             )
         except Exception as ex:
             raise CommandError(ex) from ex
