@@ -1,10 +1,7 @@
 """Module collecting support classes for OpenSSH CA support."""
 
 from .constants import OpenSshCertificateType
-from .extensions import SshHostCaExtension
-from .extensions import SshHostCaType
-from .extensions import SshUserCaExtension
-from .extensions import SshUserCaType
+from .extensions import SshHostCaExtension, SshHostCaType, SshUserCaExtension, SshUserCaType
 
 __all__ = (
     "OpenSshCertificateType",
