@@ -15,9 +15,7 @@
 
 import typing
 
-from cryptography.x509 import Extension
-from cryptography.x509 import ObjectIdentifier
-from cryptography.x509 import UnrecognizedExtension
+from cryptography.x509 import Extension, ObjectIdentifier, UnrecognizedExtension
 
 SSH_HOST_CA = ObjectIdentifier("1.2.22.2")
 SSH_USER_CA = ObjectIdentifier("1.2.22.1")
@@ -31,9 +29,7 @@ else:
 
 
 class SshHostCaType(UnrecognizedExtension):
-    """
-    CA Certs with this extension can sign OpenSSH Host keys.
-    """
+    """CA Certs with this extension can sign OpenSSH Host keys."""
 
     def __init__(self) -> None:
         super().__init__(SSH_HOST_CA, b"OpenSSH Host CA")
@@ -47,9 +43,7 @@ class SshHostCaExtension(SshHostCaExtensionBase):
 
 
 class SshUserCaType(UnrecognizedExtension):
-    """
-    CA Certs with this extension can sign OpenSSH Client / User keys.
-    """
+    """CA Certs with this extension can sign OpenSSH Client / User keys."""
 
     def __init__(self) -> None:
         super().__init__(SSH_USER_CA, b"OpenSSH User CA")
