@@ -15,10 +15,7 @@
 
 import abc
 import typing
-from typing import TYPE_CHECKING
-from typing import Any
-from typing import Generic
-from typing import TypeVar
+from typing import TYPE_CHECKING, Any, Generic, TypeVar
 
 from django.core.exceptions import ImproperlyConfigured
 from django.db import models
@@ -27,7 +24,7 @@ from django.utils import timezone
 
 from . import ca_settings
 from .acme.constants import Status
-from .typehints import Protocol
+from .typehints import Protocol, X509CertMixinTypeVar
 from .utils import sanitize_serial
 
 if not TYPE_CHECKING:
@@ -42,16 +39,17 @@ if not TYPE_CHECKING:
     ) = AcmeOrderQuerySetBase = CertificateQuerySetBase = CertificateAuthorityQuerySetBase = models.QuerySet
 
     QuerySetTypeVar = TypeVar("QuerySetTypeVar", bound=models.QuerySet)
-    X509CertMixinTypeVar = TypeVar("X509CertMixinTypeVar")
 else:  # pragma: no cover  # only used for type checking
-    from .models import AcmeAccount
-    from .models import AcmeAuthorization
-    from .models import AcmeCertificate
-    from .models import AcmeChallenge
-    from .models import AcmeOrder
-    from .models import Certificate
-    from .models import CertificateAuthority
-    from .models import X509CertMixin
+    from .models import (
+        AcmeAccount,
+        AcmeAuthorization,
+        AcmeCertificate,
+        AcmeChallenge,
+        AcmeOrder,
+        Certificate,
+        CertificateAuthority,
+        X509CertMixin,
+    )
 
     AcmeAccountQuerySetBase = models.QuerySet[AcmeAccount]
     AcmeAuthorizationQuerySetBase = models.QuerySet[AcmeAuthorization]
@@ -62,7 +60,6 @@ else:  # pragma: no cover  # only used for type checking
     CertificateQuerySetBase = models.QuerySet[Certificate]
 
     QuerySetTypeVar = TypeVar("QuerySetTypeVar", bound=models.QuerySet[X509CertMixin])
-    X509CertMixinTypeVar = TypeVar("X509CertMixinTypeVar", bound=X509CertMixin)
 
 
 class QuerySetProtocol(
