@@ -13,33 +13,27 @@
 
 """Module for handling x509 subjects."""
 
+import warnings
 from collections import abc
-from typing import Any
-from typing import Dict
-from typing import Iterable
-from typing import Iterator
-from typing import List
-from typing import Optional
-from typing import Tuple
-from typing import Union
-from typing import cast
+from typing import Any, Dict, Iterable, Iterator, List, Optional, Tuple, Union, cast
 
 from cryptography import x509
 
 from django.core.exceptions import ImproperlyConfigured
 
 from . import ca_settings
+from .deprecation import RemovedInDjangoCA123Warning, RemovedInDjangoCA124Warning
 from .typehints import ParsableSubject
-from .utils import MULTIPLE_OIDS
-from .utils import NAME_OID_MAPPINGS
-from .utils import OID_NAME_MAPPINGS
-from .utils import SUBJECT_FIELDS
-from .utils import parse_name_x509
+from .utils import MULTIPLE_OIDS, NAME_OID_MAPPINGS, OID_NAME_MAPPINGS, SUBJECT_FIELDS, parse_name_x509
 
 
 class Subject:
     """Convenience class to handle X509 Subjects.
 
+    .. deprecated:: 1.22.0
+
+       This class is deprecated and will be removed in ``django-ca==1.24.0``.
+
     This class accepts a variety of values and intelligently parses them:
 
     >>> Subject('/CN=example.com')
@@ -67,6 +61,9 @@ class Subject:
     _data: Dict[x509.ObjectIdentifier, List[str]]
 
     def __init__(self, subject: Optional[ParsableSubject] = None) -> None:
+        warnings.warn(
+            "django_ca.subject.Subject will be removed in 1.24.0.", category=RemovedInDjangoCA124Warning
+        )
         self._data = {}
 
         iterable: Iterable[
@@ -286,8 +283,18 @@ class Subject:
         return x509.Name([x509.NameAttribute(k, v) for k, v in self.fields])
 
 
-def get_default_subject() -> Subject:
-    """Get the default subject as configured by the ``CA_DEFAULT_SUBJECT`` setting."""
+def get_default_subject() -> Subject:  # pragma: no cover
+    """Get the default subject as configured by the ``CA_DEFAULT_SUBJECT`` setting.
+
+    .. deprecated:: 1.22.0
+
+       This function will be removed in 1.23.0.
+    """
+
+    warnings.warn(
+        "django_ca.subject.get_default_subject() will be removed in 1.23.0.",
+        category=RemovedInDjangoCA123Warning,
+    )
 
     try:
         return Subject(ca_settings.CA_DEFAULT_SUBJECT)
