@@ -21,15 +21,11 @@ from django import template
 from django.contrib.admin.templatetags.admin_modify import submit_row
 from django.utils.html import format_html
 from django.utils.safestring import mark_safe
+from django.utils.translation import gettext as _
 
-from ..extensions.utils import EXTENDED_KEY_USAGE_NAMES
-from ..extensions.utils import key_usage_items
-from ..extensions.utils import signed_certificate_timestamp_values
-from ..utils import add_colons
-from ..utils import bytes_to_hex
-from ..utils import format_general_name
-from ..utils import format_name
-from ..utils import int_to_hex
+from ..constants import EXTENDED_KEY_USAGE_NAMES, EXTENSION_CRITICAL_HELP, EXTENSION_RFC_DEFINITION
+from ..extensions.utils import key_usage_items, signed_certificate_timestamp_values
+from ..utils import add_colons, bytes_to_hex, format_general_name, format_name, int_to_hex
 
 register = template.Library()
 
@@ -39,6 +35,16 @@ register.filter("key_usage_items", key_usage_items)
 register.filter("signed_certificate_timestamp_values", signed_certificate_timestamp_values)
 
 
+@register.filter
+def critical_help(dotted_string: str) -> str:
+    """Return help text informing the user if the extension should be marked as critical or not."""
+    oid = x509.ObjectIdentifier(dotted_string)
+    rfc = EXTENSION_RFC_DEFINITION[oid]
+    help_text = EXTENSION_CRITICAL_HELP.get(oid, "")
+
+    return _("RFC %(rfc)s says this extension %(help_text)s.") % {"help_text": help_text, "rfc": rfc}
+
+
 @register.filter
 def access_method(
     value: x509.AuthorityInformationAccess, oid: x509.ObjectIdentifier
