@@ -24,41 +24,26 @@ import binascii
 import logging
 import os
 import typing
-from datetime import datetime
-from datetime import timedelta
+from datetime import datetime, timedelta
 from http import HTTPStatus
 
 from cryptography import x509
-from cryptography.hazmat.primitives import hashes
-from cryptography.hazmat.primitives import serialization
-from cryptography.hazmat.primitives.asymmetric import dsa
-from cryptography.hazmat.primitives.asymmetric import ec
-from cryptography.hazmat.primitives.asymmetric import rsa
+from cryptography.hazmat.primitives import hashes, serialization
+from cryptography.hazmat.primitives.asymmetric import dsa, ec, rsa
 from cryptography.hazmat.primitives.serialization import Encoding
-from cryptography.x509 import ExtensionNotFound
-from cryptography.x509 import OCSPNonce
-from cryptography.x509 import load_pem_x509_certificate
-from cryptography.x509 import ocsp
+from cryptography.x509 import ExtensionNotFound, OCSPNonce, load_pem_x509_certificate, ocsp
 
 from django.core.cache import cache
-from django.http import HttpRequest
-from django.http import HttpResponse
-from django.http import HttpResponseServerError
+from django.http import HttpRequest, HttpResponse, HttpResponseServerError
 from django.utils.decorators import method_decorator
 from django.views.decorators.csrf import csrf_exempt
 from django.views.generic.base import View
 from django.views.generic.detail import SingleObjectMixin
 
 from . import ca_settings
-from .models import Certificate
-from .models import CertificateAuthority
-from .typehints import Literal
-from .typehints import PrivateKeyTypes
-from .utils import SERIAL_RE
-from .utils import get_crl_cache_key
-from .utils import int_to_hex
-from .utils import parse_encoding
-from .utils import read_file
+from .models import Certificate, CertificateAuthority
+from .typehints import Literal, PrivateKeyTypes
+from .utils import SERIAL_RE, get_crl_cache_key, int_to_hex, parse_encoding, read_file
 
 log = logging.getLogger(__name__)
 
@@ -99,6 +84,9 @@ class CertificateRevocationListView(View, SingleObjectMixinBase):
     content_type = None
     """Value of the Content-Type header used in the response. For CRLs in PEM format, use ``text/plain``."""
 
+    include_issuing_distribution_point: typing.Optional[bool] = None
+    """Boolean flag to force inclusion/exclusion of IssuingDistributionPoint extension."""
+
     def get(self, request: HttpRequest, serial: str) -> HttpResponse:
         # pylint: disable=missing-function-docstring; standard Django view function
         encoding = parse_encoding(request.GET.get("encoding", self.type))
@@ -107,9 +95,20 @@ class CertificateRevocationListView(View, SingleObjectMixinBase):
         crl = cache.get(cache_key)
         if crl is None:
             ca = self.get_object()
+
+            # Catch this case early so that we can give a better error message
+            if self.include_issuing_distribution_point is True and ca.parent is None and self.scope is None:
+                raise ValueError(
+                    "Cannot add IssuingDistributionPoint extension to CRLs with no scope for root CAs."
+                )
+
             encoding = parse_encoding(self.type)
             crl = ca.get_crl(
-                expires=self.expires, algorithm=self.digest, password=self.password, scope=self.scope
+                expires=self.expires,
+                algorithm=self.digest,
+                password=self.password,
+                scope=self.scope,
+                include_issuing_distribution_point=self.include_issuing_distribution_point,
             )
             crl = crl.public_bytes(encoding)
             cache.set(cache_key, crl, self.expires)
@@ -354,7 +353,7 @@ class GenericCAIssuersView(View):
     """Generic view that returns a CA public key in DER format.
 
     This view serves the URL named in the ``issuers`` key in the
-    :py:class:`~django_ca.extensions.AuthorityInformationAccess` extension.
+    :py:class:`~cg:cryptography.x509.AuthorityInformationAccess` extension.
     """
 
     def get(self, request: HttpRequest, serial: str) -> HttpResponse:
